sqlobject.inheritance.tests.test_asdict module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_asdict module

class `sqlobject.inheritance.tests.test_asdict.` `EmployeeAD`(**kw)

  Bases: `sqlobject.inheritance.tests.test_asdict.InheritablePersonAD`

  property `firstName`
  `j` = employee_a_d
  property `lastName`
  `q` = employee_a_d
  property `so_position`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'EmployeeAD'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_asdict.InheritablePersonAD`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_asdict.EmployeeAD`

    `table` = 'employee_a_d'

class `sqlobject.inheritance.tests.test_asdict.` `InheritablePersonAD`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  classmethod `byLastName`(val, connection=None)
  property `childName`
  property `firstName`
  `j` = inheritable_person_a_d
  property `lastName`
  `q` = inheritable_person_a_d
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'EmployeeAD': <class 'sqlobject.inheritance.tests.test_asdict.EmployeeAD'>, 'ManagerAD': <class 'sqlobject.inheritance.tests.test_asdict.ManagerAD'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_asdict.InheritablePersonAD`

    `table` = 'inheritable_person_a_d'

class `sqlobject.inheritance.tests.test_asdict.` `ManagerAD`(**kw)

  Bases: `sqlobject.inheritance.tests.test_asdict.InheritablePersonAD`

  property `childName`
  property `department`
  property `firstName`
  `j` = manager_a_d
  property `lastName`
  `q` = manager_a_d
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'ManagerAD'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_asdict.InheritablePersonAD`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_asdict.ManagerAD`

    `table` = 'manager_a_d'

`sqlobject.inheritance.tests.test_asdict.` `test_asDict`()

`sqlobject.inheritance.tests.test_asdict.` `test_getColumns`()